[![PyPI](https://img.shields.io/pypi/v/hydra-core)](https://pypi.org/project/hydra-core/)
[![CircleCI](https://img.shields.io/circleci/build/github/facebookresearch/hydra?token=af199cd2deca9e70e53776f9ded96284b10687e9)](https://circleci.com/gh/facebookresearch/hydra)
![PyPI - License](https://img.shields.io/pypi/l/hydra-core)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/hydra-core)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/hydra-core.svg)](https://pypistats.org/packages/hydra-core)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Total alerts](https://img.shields.io/lgtm/alerts/g/facebookresearch/hydra.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/facebookresearch/hydra/alerts/)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/facebookresearch/hydra.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/facebookresearch/hydra/context:python)
[![](https://img.shields.io/badge/zulip-join_chat-brightgreen.svg)](https://hydra-framework.zulipchat.com)

# Hydra
A framework for elegantly configuring complex applications.

Check the [website](https://hydra.cc/) for more information.

## License
Hydra is licensed under [MIT License](LICENSE).

## Community
Ask questions in the chat or StackOverflow (Use the tag #fb-hydra or #omegaconf):
* [Chat](https://hydra-framework.zulipchat.com)
* [StackOverflow](https://stackexchange.com/filters/391828/hydra-questions)
* [Twitter](https://twitter.com/Hydra_Framework)


## Citing Hydra
If you use Hydra in your research please use the following BibTeX entry:
```text
@Misc{,
  author =       {Omry Yadan},
  title =        {A framework for elegantly configuring complex applications},
  howpublished = {Github},
  year =         {2019},
  url =          {https://github.com/facebookresearch/hydra}
}
```
